# This protocol is designed to work in a GNU/Linux terminal with bash interpreter, packages installed are perl-rename, QIIME2 and sourcetracker2
# Previous to Qiime2
# First, open a terminal in the working directory
# Rename sequencing files in order to have more consistent names
perl-rename "s/F(\d.fastq)/0\1/" *.fastq
perl-rename "s/F(\d{2}.fastq)/\1/" *.fastq

# Put the chip name to each barcode this was performed with each chip
perl-rename "s/(.*)_(\d*)/CJJ_2_\2/" *.fastq

# Make a list with the absolute path of the fastq for the manifest.tsv file
ls -d $PWD/*.fastq > analysis/manifest.tsv

# Sample names were assigned in the manifest.tsv file in a spreadsheet with LibreOffice

# QIIME2 analysis
# Activate conda environment

conda activate qiime2

# Then, sequences were imported as qiime artifact

qiime tools import \
  --type 'SampleData[SequencesWithQuality]' \
  --input-path analysis/manifest.tsv \
  --input-format SingleEndFastqManifestPhred33V2 \
  --output-path analysis/CJJC_demux.qza

# Generate a summary of the sequences

qiime demux summarize \
  --i-data analysis/CJJC_demux.qza \
  --o-visualization analysis/demux.qzv

# It was observed in the summary that 25% of the sequences were lower than 174 nt
# So, dada2 denoise was performed for 170 nt trimm and filtering:

qiime dada2 denoise-single \
  --i-demultiplexed-seqs analysis/CJJC_demux.qza \
  --p-trim-left 0 \
  --p-trunc-len 170 \
  --o-representative-sequences analysis/CJJC_rep-seqs.qza \
  --o-table analysis/CJJC_table.qza \
  --o-denoising-stats analysis/CJJC_stats.qza

# Generate phylogenetic tree

qiime phylogeny align-to-tree-mafft-fasttree \
  --i-sequences analysis/CJJC_rep-seqs.qza \
  --o-alignment analysis/aligned-rep-seqs.qza \
  --o-masked-alignment analysis/masked-aligned-rep-seqs.qza \
  --o-tree analysis/unrooted-tree.qza \
  --o-rooted-tree analysis/rooted-tree.qza


# Taxonomic annotation with blast method and Silva database was performed

qiime feature-classifier classify-consensus-blast \
  --i-query analysis/CJJC_rep-seqs.qza \
  --i-reference-reads classifier/silva-138-99-seqs.qza \
  --i-reference-taxonomy classifier/silva-138-99-tax.qza \
  --p-perc-identity 0.97 \
  --o-classification analysis/taxonomy.qza

# Filter not relevant taxa

qiime taxa filter-table \
  --i-table analysis/CJJC_table.qza \
  --i-taxonomy analysis/taxonomy.qza \
  --p-exclude Chloroplast,Eukaryota \
  --o-filtered-table analysis/filtered_table.qza

# And barplot representation for relative abundances

qiime taxa barplot \
  --i-table analysis/filtered_table.qza \
  --i-taxonomy analysis/taxonomy.qza \
  --o-visualization analysis/visualizations/barplot.qzv

# Samples were separated by group, so sequence length could be calculated for each group

qiime demux filter-samples \
  --i-demux analysis/CJJC_demux.qza \
  --m-metadata-file analysis/metadata.tsv \
  --p-where "[group]='CB'" \
  --o-filtered-demux analysis/sub/CB_demux.qza

qiime demux filter-samples \
  --i-demux analysis/CJJC_demux.qza \
  --m-metadata-file analysis/metadata.tsv \
  --p-where "[group]='CM'" \
  --o-filtered-demux analysis/sub/CM_demux.qza

qiime demux filter-samples \
  --i-demux analysis/CJJC_demux.qza \
  --m-metadata-file analysis/metadata.tsv \
  --p-where "[group]='LM'" \
  --o-filtered-demux analysis/sub/LM_demux.qza

qiime demux summarize \
  --i-data analysis/sub/LM_demux.qza \
  --o-visualization analysis/LM_demux.qzv

qiime demux summarize \
  --i-data analysis/sub/CM_demux.qza \
  --o-visualization analysis/CM_demux.qzv

qiime demux summarize \
  --i-data analysis/sub/CB_demux.qza \
  --o-visualization analysis/CB_demux.qzv

# Rarefraction of alpha diversity

qiime diversity alpha-rarefaction \
  --i-table analysis/filtered_table_sample.qza \
  --i-phylogeny analysis/rooted-tree.qza \
  --p-max-depth 1000 \
  --m-metadata-file analysis/metadata_sampleB.tsv \
  --o-visualization alpha-rarefaction.qzv


# Sourcetracker analysis was performed with sourcetracker2 from https://github.com/biota/sourcetracker2 based on this notebook https://notebook.community/biota/sourcetracker2/ipynb/Sourcetracking-using-QIIME2
# Sourcetracker2 was installed within QIIME2 conda environment

qiime sourcetracker2 gibbs \
    --i-feature-table analysis/filtered_table.qza \
    --m-sample-metadata-file analysis/metadata_source.tsv \
    --p-source-sink-column SourceSink \
    --p-source-rarefaction-depth 950 \
    --p-sink-rarefaction-depth 950 \
    --p-no-loo \
    --p-source-column-value source \
    --p-sink-column-value sink \
    --p-source-category-column group \
    --output-dir analysis/sourcetracker
